#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class BaseDirEntry :
    def __init__( self):
        self.displayName = None
        self.entryUid = None
        self.accountType = None
        self.kind = None
        pass

class __BaseDirEntrySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = BaseDirEntry()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        displayNameValue = value['displayName']
        instance.displayName = serder.STRING.parse(displayNameValue)
        entryUidValue = value['entryUid']
        instance.entryUid = serder.STRING.parse(entryUidValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeValue = value['accountType']
        instance.accountType = __BaseDirEntryAccountTypeSerDer__().parse(accountTypeValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        kindValue = value['kind']
        instance.kind = __BaseDirEntryKindSerDer__().parse(kindValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        displayNameValue = value.displayName
        instance["displayName"] = serder.STRING.encode(displayNameValue)
        entryUidValue = value.entryUid
        instance["entryUid"] = serder.STRING.encode(entryUidValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeValue = value.accountType
        instance["accountType"] = __BaseDirEntryAccountTypeSerDer__().encode(accountTypeValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        kindValue = value.kind
        instance["kind"] = __BaseDirEntryKindSerDer__().encode(kindValue)
        return instance

